6. Additional module repositories — Django Chuck 1.0 documentation

### Navigation

- index
- next |
- previous |
- Django Chuck 1.0 documentation »

# 6. Additional module repositories

Currently their is only the extra repository from Notch Interactive available on Github. Feel free to send an email to chuck@notch-interactive.com if you want to add your Chuck module repository to this list.

To add another module repository you have to download it to a local folder and define the `module_basedirs` variable in your config file `~/.django_chuck.conf`.

    module_basedirs="/some/dir/to/additionial-modules","."

### Navigation

- index
- next |
- previous |
- Django Chuck 1.0 documentation »